Struct Layer

pub struct Layer<const ROW: usize, const COL: usize, const ENCODER_COUNT: usize> {
    pub keymap: LayerKeymap<ROW, COL>,
    pub encoder_keys: [(Option<KeyCode>, Option<KeyCode>); ENCODER_COUNT],
    pub arrow_mouse: bool,
}
Layer definition

This structure holds information about layer. This contains keymap and arrowmouse flag.

Fields

keymap: LayerKeymap<ROW, COL>encoder_keys: [(Option<KeyCode>, Option<KeyCode>); ENCODER_COUNT]

Keycode assigned to each encoder.

Left of tuple is for counter clockwise, right of tuple is for clockwise. None has special meaning that it is not assigned and inherits keycode from previous layer.

arrow_mouse: bool

Implementations

Source

impl<const ROW: usize, const COL: usize, const ENCODER_COUNT: usize> Layer<ROW, COL, ENCODER_COUNT>

pub const fn const_default() -> Self